==> beast-trans-api-2.4.0-sources.jar: com/thebeastshop/trans/enums/TsOrderBusinessTypeEnum.java <==
package com.thebeastshop.trans.enums;

/**
 * Created by feilong.gao on 2017/2/21.
 */
public enum TsOrderBusinessTypeEnum {

    NORMAL("01", "普通订单"),
    MONTHLY_FLOWER("02", "鲜花月送订单"),
    CUSTOMIZE("03", "含定制商品订单"),
    SPD("06", "浦发兑换订单"),
    FURNITURE("07", "大家具订单"),
    JBR("08", "井柏然圣诞集赞订单"),
    EXCHANGE("09", "积分兑换"),
    GROUPON("10", "团购"),
    DEPOSIT("11", "定金"),
    FINAL("12", "尾款"),
    CLASSROOM("13", "野兽课堂"),
    LADDER_BUY("16", "阶梯购"),
    WECHAT_GIFT("17", "微信送礼");

    private String code;
    private String desc;

    TsOrderBusinessTypeEnum(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    /**
     * 获取Code
     *
     * @return
     */
    public String getCode() {
        return code;
    }

    /**
     * 获取描述
     *
     * @return
     */
    public String getDesc() {
        return desc;
    }

    /**
     * 根据code获取
     *
     * @param code
     * @return
     */
    public static TsOrderBusinessTypeEnum getByCode(Integer code) {
        if (code != null) {
            for (TsOrderBusinessTypeEnum value : TsOrderBusinessTypeEnum.values()) {
                if (Integer.parseInt(value.getCode()) == code) {
                    return value;
                }
            }
        }
        return NORMAL;
    }

    /**
     * 根据Code获取描述
     *
     * @param code
     * @return
     */
    public static String getDesc(Integer code) {
        for (TsOrderBusinessTypeEnum value : TsOrderBusinessTypeEnum.values()) {
            if (value.getCode().equals(code)) {
                return value.getDesc();
            }
        }
        return "";
    }
}

==> beast-trans-api-2.4.7-20250709.063739-8-sources.jar: com/thebeastshop/trans/enums/TsOrderBusinessTypeEnum.java <==
package com.thebeastshop.trans.enums;

import com.google.common.collect.Lists;

import java.util.List;

/**
 * Created by feilong.gao on 2017/2/21.
 */
public enum TsOrderBusinessTypeEnum {

    NORMAL("01", "普通订单"),
    MONTHLY_FLOWER("02", "鲜花月送订单"),
    CUSTOMIZE("03", "含定制商品订单"),
    SPD("06", "浦发兑换订单"),
    FURNITURE("07", "大家具订单"),
    JBR("08", "井柏然圣诞集赞订单"),
    EXCHANGE("09", "积分兑换"),
    GROUPON("10", "团购"),
    DEPOSIT("11", "定金"),
    FINAL("12", "尾款"),
    CLASSROOM("13", "野兽课堂"),
    LADDER_BUY("16", "阶梯购"),
    WECHAT_GIFT("17", "微信送礼");

    private String code;
    private String desc;

    TsOrderBusinessTypeEnum(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    /**
     * 获取Code
     *
     * @return
     */
    public String getCode() {
        return code;
    }

    /**
     * 获取描述
     *
     * @return
     */
    public String getDesc() {
        return desc;
    }

    /**
     * 根据code获取
     *
     * @param code
     * @return
     */
    public static TsOrderBusinessTypeEnum getByCode(Integer code) {
        if (code != null) {
            for (TsOrderBusinessTypeEnum value : TsOrderBusinessTypeEnum.values()) {
                if (Integer.parseInt(value.getCode()) == code) {
                    return value;
                }
            }
        }
        return NORMAL;
    }

    /**
     * 根据Code获取描述
     *
     * @param code
     * @return
     */
    public static String getDesc(Integer code) {
        for (TsOrderBusinessTypeEnum value : TsOrderBusinessTypeEnum.values()) {
            if (value.getCode().equals(code)) {
                return value.getDesc();
            }
        }
        return "";
    }

    /**
     *
     * @return
     */
    public static List<Integer> getCancelTypes() {
        return Lists.newArrayList(Integer.valueOf(NORMAL.code), Integer.valueOf(EXCHANGE.code));
    }
}
